@@ -1,5 +1,19 @@
-import json
 from . import six
+import json
+
+
+class JSONRPCException(Exception):
+
+    """ JSON-RPC Exception."""
+
+    pass
+
+
+class JSONRPCInvalidRequestException(JSONRPCException):
+
+    """ Request is not valid."""
+
+    pass
 
 
 class JSONRPCError(object):
@@ -9,18 +23,20 @@ class JSONRPCError(object):
     When a rpc call encounters an error, the Response Object MUST contain the
     error member with a value that is a Object with the following members:
 
-    code: A Number that indicates the error type that occurred.
+    :param int code: A Number that indicates the error type that occurred.
         This MUST be an integer.
 
-    message: A String providing a short description of the error.
+    :param str message: A String providing a short description of the error.
         The message SHOULD be limited to a concise single sentence.
 
-    data: A Primitive or Structured value that contains additional information
-        about the error.
+    :param data: A Primitive or Structured value that contains additional
+        information about the error.
         This may be omitted.
         The value of this member is defined by the Server (e.g. detailed error
         information, nested errors etc.).
 
+    :type data: None or int or str or dict or list
+
     The error codes from and including -32768 to -32000 are reserved for
     pre-defined errors. Any code within this range, but not defined explicitly
     below is reserved for future use. The error codes are nearly the same as
@@ -33,39 +49,39 @@ class JSONRPCError(object):
     deserialize = staticmethod(json.loads)
 
     def __init__(self, code=None, message=None, data=None):
-        self._dict = dict()
+        self._data = dict()
         self.code = getattr(self.__class__, "CODE", code)
         self.message = getattr(self.__class__, "MESSAGE", message)
         self.data = data
 
     def __get_code(self):
-        return self._dict["code"]
+        return self._data["code"]
 
     def __set_code(self, value):
         if not isinstance(value, six.integer_types):
             raise ValueError("Error code should be integer")
 
-        self._dict["code"] = value
+        self._data["code"] = value
 
     code = property(__get_code, __set_code)
 
     def __get_message(self):
-        return self._dict["message"]
+        return self._data["message"]
 
     def __set_message(self, value):
         if not isinstance(value, six.string_types):
             raise ValueError("Error message should be string")
 
-        self._dict["message"] = value
+        self._data["message"] = value
 
     message = property(__get_message, __set_message)
 
     def __get_data(self):
-        return self._dict.get("data")
+        return self._data.get("data")
 
     def __set_data(self, value):
         if value is not None:
-            self._dict["data"] = value
+            self._data["data"] = value
 
     data = property(__get_data, __set_data)
 
@@ -77,7 +93,7 @@ class JSONRPCError(object):
 
     @property
     def json(self):
-        return self.serialize(self._dict)
+        return self.serialize(self._data)
 
 
 class JSONRPCParseError(JSONRPCError):
@@ -151,3 +167,16 @@ class JSONRPCServerError(JSONRPCError):
 
     CODE = -32000
     MESSAGE = "Server error"
+
+
+class JSONRPCDispatchException(JSONRPCException):
+
+    """ JSON-RPC Dispatch Exception.
+
+    Should be thrown in dispatch methods.
+
+    """
+
+    def __init__(self, code=None, message=None, data=None, *args, **kwargs):
+        super(JSONRPCDispatchException, self).__init__(args, kwargs)
+        self.error = JSONRPCError(code=code, data=data, message=message)
